=== modified file 'lib/canonical/config/schema-lazr.conf'
--- lib/canonical/config/schema-lazr.conf	2011-05-06 13:55:19 +0000
+++ lib/canonical/config/schema-lazr.conf	2011-06-01 15:47:47 +0000
@@ -522,6 +522,8 @@
 # Import only this many revisions from svn (via bzr-svn) at once.
 svn_revisions_import_limit: 5000
 
+# Import only this many revisions from hg at once.
+hg_revisions_import_limit: 5000
 
 [codeimportdispatcher]
 # The directory where the code import worker should be directed to

=== modified file 'lib/lp/code/bzr.py'
--- lib/lp/code/bzr.py	2010-08-20 20:31:18 +0000
+++ lib/lp/code/bzr.py	2011-06-02 19:27:36 +0000
@@ -213,6 +213,11 @@
         "1.6.1-subtree with B+Tree indices.\n"
         )
 
+    BZR_DEV_8 = DBItem(306,
+        "Bazaar development format 8\n",
+        "2a repository format with support for nested trees.\n"
+        )
+
     BZR_CHK1 = DBItem(400,
         "Bazaar development format - group compression and chk inventory"
         " (needs bzr.dev from 1.14)\n",
@@ -269,6 +274,7 @@
     RepositoryFormat.BZR_DEV_1_SUBTREE,
     RepositoryFormat.BZR_DEV_2,
     RepositoryFormat.BZR_DEV_2_SUBTREE,
+    RepositoryFormat.BZR_DEV_8,
     RepositoryFormat.BZR_CHK1,
     RepositoryFormat.BZR_CHK2,
     RepositoryFormat.BZR_CHK_2A)

=== modified file 'lib/lp/code/interfaces/tests/test_branch.py'
--- lib/lp/code/interfaces/tests/test_branch.py	2010-08-20 20:31:18 +0000
+++ lib/lp/code/interfaces/tests/test_branch.py	2011-06-02 19:27:36 +0000
@@ -8,7 +8,7 @@
 from unittest import TestLoader
 
 from bzrlib.branch import BranchFormat as BzrBranchFormat
-from bzrlib.bzrdir import BzrDirFormat
+from bzrlib.bzrdir import BzrProber
 from bzrlib.repository import format_registry as repo_format_registry
 
 from lp.code.bzr import (
@@ -28,7 +28,7 @@
     """
 
     def test_control_format_complement(self):
-        self.bzrlib_is_subset(BzrDirFormat._formats.keys(), ControlFormat)
+        self.bzrlib_is_subset(BzrProber._formats.keys(), ControlFormat)
 
     def test_branch_format_complement(self):
         self.bzrlib_is_subset(BzrBranchFormat._formats.keys(), BranchFormat)

=== modified file 'lib/lp/codehosting/codeimport/tests/servers.py'
--- lib/lp/codehosting/codeimport/tests/servers.py	2010-12-20 03:21:03 +0000
+++ lib/lp/codehosting/codeimport/tests/servers.py	2011-06-02 10:48:54 +0000
@@ -12,9 +12,11 @@
 
 __metaclass__ = type
 
+from cStringIO import StringIO
 import os
 import shutil
 import signal
+import stat
 import subprocess
 import tempfile
 import time
@@ -26,8 +28,10 @@
     join as urljoin,
     )
 import CVS
+import dulwich.index
+from dulwich.objects import Blob
 from dulwich.repo import Repo as GitRepo
-import pysvn
+import subvertpy.ra
 import svn_oo
 
 from lp.services.log.logger import BufferLogger
@@ -73,6 +77,10 @@
         self.repository_path = os.path.abspath(repository_path)
         self._use_svn_serve = use_svn_serve
 
+    def _get_ra(self, url):
+        return subvertpy.ra.RemoteAccess(url,
+            auth=subvertpy.ra.Auth([subvertpy.ra.get_username_provider()]))
+
     def createRepository(self, path):
         """Create a Subversion repository at `path`."""
         svn_oo.Repository.Create(path, BufferLogger())
@@ -98,9 +106,8 @@
             delay = 0.1
             for i in range(10):
                 try:
-                    client = pysvn.Client()
-                    client.ls(self.get_url())
-                except pysvn.ClientError, e:
+                    ra = self._get_ra(self.get_url())
+                except subvertpy.SubversionException, e:
                     if 'Connection refused' in str(e):
                         time.sleep(delay)
                         delay *= 1.5
@@ -117,7 +124,6 @@
             os.kill(self._svnserve.pid, signal.SIGINT)
             self._svnserve.communicate()
 
-    @run_in_temporary_directory
     def makeBranch(self, branch_name, tree_contents):
         """Create a branch on the Subversion server called `branch_name`.
 
@@ -126,27 +132,31 @@
             tuples of (relative filename, file contents).
         """
         branch_url = self.makeDirectory(branch_name)
-        client = pysvn.Client()
-        branch_path = os.path.abspath(branch_name)
-        client.checkout(branch_url, branch_path)
-        build_tree_contents(
-            [(os.path.join(branch_path, filename), content)
-             for filename, content in tree_contents])
-        client.add(
-            [os.path.join(branch_path, filename)
-             for filename in os.listdir(branch_path)
-             if not filename.startswith('.')], recurse=True)
-        client.checkin(branch_path, 'Import', recurse=True)
+        ra = self._get_ra(branch_url)
+        editor = ra.get_commit_editor({"svn:log": "Import"})
+        root = editor.open_root()
+        for filename, content in tree_contents:
+            f = root.add_file(filename)
+            try:
+                subvertpy.delta.send_stream(StringIO(content),
+                    f.apply_textdelta())
+            finally:
+                f.close()
+        root.close()
+        editor.close()
         return branch_url
 
     def makeDirectory(self, directory_name, commit_message=None):
         """Make a directory on the repository."""
         if commit_message is None:
             commit_message = 'Make %r' % (directory_name,)
-        url = urljoin(self.get_url(), directory_name)
-        client = pysvn.Client()
-        client.mkdir(url, commit_message)
-        return url
+        ra = self._get_ra(self.get_url())
+        editor = ra.get_commit_editor({"svn:log": commit_message})
+        root = editor.open_root()
+        root.add_directory(directory_name).close()
+        root.close()
+        editor.close()
+        return urljoin(self.get_url(), directory_name)
 
 
 class CVSServer(Server):
@@ -201,16 +211,19 @@
         self.repo_url = repo_url
 
     def makeRepo(self, tree_contents):
-        from bzrlib.plugins.git.tests import GitBranchBuilder
         wd = os.getcwd()
         try:
             os.chdir(self.repo_url)
-            GitRepo.init(".")
-            builder = GitBranchBuilder()
-            for filename, contents in tree_contents:
-                builder.set_file(filename, contents, False)
-            builder.commit('Joe Foo <joe@foo.com>', u'<The commit message>')
-            builder.finish()
+            repo = GitRepo.init(".")
+            blobs = [
+                (Blob.from_string(contents), filename) for (filename, contents)
+                in tree_contents]
+            repo.object_store.add_objects(blobs)
+            root_id = dulwich.index.commit_tree(repo.object_store, [
+                (filename, b.id, stat.S_IFREG | 0644)
+                for (b, filename) in blobs])
+            repo.do_commit(committer='Joe Foo <joe@foo.com>',
+                message=u'<The commit message>', tree=root_id)
         finally:
             os.chdir(wd)
 

=== modified file 'lib/lp/codehosting/codeimport/tests/test_worker.py'
--- lib/lp/codehosting/codeimport/tests/test_worker.py	2011-05-17 12:59:37 +0000
+++ lib/lp/codehosting/codeimport/tests/test_worker.py	2011-06-01 15:52:13 +0000
@@ -1000,19 +1000,9 @@
         worker = self.makeImportWorker(source_details)
         self.assertRaises(NotBranchError, worker.run)
 
-
-class PartialTest:
-    """A test case for incremental imports.
-
-    When all foreign branch plugins support incremental imports, this can go
-    into PullingImportWorkerTests.  For now though, bzr-hg still lacks the
-    needed support.
-    """
-
     def test_partial(self):
         # Only config.codeimport.revisions_import_limit will be imported in a
-        # given run.  When bzr-svn and bzr-hg support revision import limits,
-        # this test case can be moved up to PullingImportWorkerTests.
+        # given run.
         worker = self.makeImportWorker(self.makeSourceDetails(
             'trunk', [('README', 'Original contents')]))
         self.makeForeignCommit(worker.source_details)
@@ -1021,6 +1011,7 @@
             'codeimport',
             git_revisions_import_limit=self.foreign_commit_count-1,
             svn_revisions_import_limit=self.foreign_commit_count-1,
+            hg_revisions_import_limit=self.foreign_commit_count-1,
             )
         self.assertEqual(
             CodeImportWorkerExitCode.SUCCESS_PARTIAL, worker.run())
@@ -1028,9 +1019,8 @@
             CodeImportWorkerExitCode.SUCCESS, worker.run())
 
 
-
 class TestGitImport(WorkerTest, TestActualImportMixin,
-                    PullingImportWorkerTests, PartialTest):
+                    PullingImportWorkerTests):
 
     rcstype = 'git'
 
@@ -1132,8 +1122,7 @@
 
 
 class TestBzrSvnImport(WorkerTest, SubversionImportHelpers,
-                       TestActualImportMixin, PullingImportWorkerTests,
-                       PartialTest):
+                       TestActualImportMixin, PullingImportWorkerTests):
 
     rcstype = 'bzr-svn'
 

=== modified file 'lib/lp/codehosting/codeimport/worker.py'
--- lib/lp/codehosting/codeimport/worker.py	2011-05-19 09:49:46 +0000
+++ lib/lp/codehosting/codeimport/worker.py	2011-06-01 15:59:45 +0000
@@ -545,24 +545,20 @@
 class PullingImportWorker(ImportWorker):
     """An import worker for imports that can be done by a bzr plugin.
 
-    Subclasses need to implement `format_classes`.
+    Subclasses need to implement `probers`.
     """
 
     needs_bzr_tree = False
 
     @property
-    def format_classes(self):
-        """The format classes that should be tried for this import."""
+    def probers(self):
+        """The probers that should be tried for this import."""
         raise NotImplementedError
 
-    def getExtraPullArgs(self):
-        """Return extra arguments to `InterBranch.pull`.
-
-        This method only really exists because only bzr-git and bzr-svn
-        support the 'limit' argument to this method.  When bzr-hg plugin does
-        too, this method can go away.
+    def getRevisionLimit(self):
+        """Return maximum number of revisions to fetch (None for no limit).
         """
-        return {}
+        return None
 
     def _doImport(self):
         self._logger.info("Starting job.")
@@ -574,9 +570,10 @@
                 "Getting exising bzr branch from central store.")
             bazaar_branch = self.getBazaarBranch()
             transport = get_transport(self.source_details.url)
-            for format_class in self.format_classes:
+            for prober_kls in self.probers:
+                prober = prober_kls()
                 try:
-                    format = format_class.probe_transport(transport)
+                    format = prober.probe_transport(transport)
                     break
                 except NotBranchError:
                     pass
@@ -586,19 +583,19 @@
             remote_branch_tip = remote_branch.last_revision()
             inter_branch = InterBranch.get(remote_branch, bazaar_branch)
             self._logger.info("Importing branch.")
-            pull_result = inter_branch.pull(
-                overwrite=True, **self.getExtraPullArgs())
+            inter_branch.fetch(limit=self.getRevisionLimit())
+            if bazaar_branch.repository.has_revision(remote_branch_tip):
+                pull_result = inter_branch.pull(overwrite=True)
+                if pull_result.old_revid != pull_result.new_revid:
+                    result = CodeImportWorkerExitCode.SUCCESS
+                else:
+                    result = CodeImportWorkerExitCode.SUCCESS_NOCHANGE
+            else:
+                result = CodeImportWorkerExitCode.SUCCESS_PARTIAL
             self._logger.info("Pushing local import branch to central store.")
             self.pushBazaarBranch(bazaar_branch)
-            last_imported_revison = bazaar_branch.last_revision()
             self._logger.info("Job complete.")
-            if last_imported_revison == remote_branch_tip:
-                if pull_result.old_revid != pull_result.new_revid:
-                    return CodeImportWorkerExitCode.SUCCESS
-                else:
-                    return CodeImportWorkerExitCode.SUCCESS_NOCHANGE
-            else:
-                return CodeImportWorkerExitCode.SUCCESS_PARTIAL
+            return result
         finally:
             bzrlib.ui.ui_factory = saved_factory
 
@@ -610,16 +607,15 @@
     """
 
     @property
-    def format_classes(self):
-        """See `PullingImportWorker.opening_format`."""
-        # We only return LocalGitBzrDirFormat for tests.
+    def probers(self):
+        """See `PullingImportWorker.probers`."""
         from bzrlib.plugins.git import (
-            LocalGitBzrDirFormat, RemoteGitBzrDirFormat)
-        return [LocalGitBzrDirFormat, RemoteGitBzrDirFormat]
+            LocalGitProber, RemoteGitProber)
+        return [LocalGitProber, RemoteGitProber]
 
-    def getExtraPullArgs(self):
-        """See `PullingImportWorker.getExtraPullArgs`."""
-        return {'limit': config.codeimport.git_revisions_import_limit}
+    def getRevisionLimit(self):
+        """See `PullingImportWorker.getRevisionLimit`."""
+        return config.codeimport.git_revisions_import_limit
 
     def getBazaarBranch(self):
         """See `ImportWorker.getBazaarBranch`.
@@ -666,11 +662,14 @@
     """
 
     @property
-    def format_classes(self):
-        """See `PullingImportWorker.opening_format`."""
-        # We only return HgLocalRepository for tests.
-        from bzrlib.plugins.hg import HgBzrDirFormat
-        return [HgBzrDirFormat]
+    def probers(self):
+        """See `PullingImportWorker.probers`."""
+        from bzrlib.plugins.hg import HgProber
+        return [HgProber]
+
+    def getRevisionLimit(self):
+        """See `PullingImportWorker.getRevisionLimit`."""
+        return config.codeimport.hg_revisions_import_limit
 
     def getBazaarBranch(self):
         """See `ImportWorker.getBazaarBranch`.
@@ -714,12 +713,12 @@
 class BzrSvnImportWorker(PullingImportWorker):
     """An import worker for importing Subversion via bzr-svn."""
 
-    def getExtraPullArgs(self):
-        """See `PullingImportWorker.getExtraPullArgs`."""
-        return {'limit': config.codeimport.svn_revisions_import_limit}
+    def getRevisionLimit(self):
+        """See `PullingImportWorker.getRevisionLimit`."""
+        return config.codeimport.svn_revisions_import_limit
 
     @property
-    def format_classes(self):
-        """See `PullingImportWorker.opening_format`."""
-        from bzrlib.plugins.svn.format import SvnRemoteFormat
-        return [SvnRemoteFormat]
+    def probers(self):
+        """See `PullingImportWorker.probers`."""
+        from bzrlib.plugins.svn import SvnRemoteProber
+        return [SvnRemoteProber]

=== modified file 'lib/lp/codehosting/puller/tests/__init__.py'
--- lib/lp/codehosting/puller/tests/__init__.py	2010-08-20 20:31:18 +0000
+++ lib/lp/codehosting/puller/tests/__init__.py	2011-06-02 11:16:47 +0000
@@ -12,8 +12,10 @@
 
 from bzrlib import urlutils
 from bzrlib.tests import (
+    TestCaseWithTransport,
+    )
+from bzrlib.tests.http_server import (
     HttpServer,
-    TestCaseWithTransport,
     )
 from bzrlib.tests.http_server import (
     TestingHTTPServer,
@@ -208,6 +210,6 @@
         # tests, and the default behaviour of the HttpServer is to use daemon
         # threads and let the garbage collector get them, however this causes
         # issues with the test runner.
-        self.addCleanup(http_server._http_thread.join)
+        self.addCleanup(http_server._server_thread.join)
         self.addCleanup(http_server.stop_server)
         return http_server.get_url().rstrip('/')

=== modified file 'lib/lp/codehosting/puller/worker.py'
--- lib/lp/codehosting/puller/worker.py	2010-08-20 20:31:18 +0000
+++ lib/lp/codehosting/puller/worker.py	2011-06-03 01:00:53 +0000
@@ -512,12 +512,13 @@
         SilentUIFactory.__init__(self)
         self.puller_worker_protocol = puller_worker_protocol
 
-    def get_boolean(self, prompt):
+    def confirm_action(self, prompt, confirmation_id, args):
         """If we're asked to break a lock like a stale lock of ours, say yes.
         """
-        assert prompt.startswith('Break '), (
-            "Didn't expect prompt %r" % (prompt,))
+        assert confirmation_id == 'bzrlib.lockdir.break', \
+            "Didn't expect confirmation id %r" % (confirmation_id,)
         branch_id = self.puller_worker_protocol.branch_id
+        prompt = prompt % args
         if get_lock_id_for_branch_id(branch_id) in prompt:
             return True
         else:

=== modified file 'lib/lp/codehosting/tests/test_bzrutils.py'
--- lib/lp/codehosting/tests/test_bzrutils.py	2010-08-20 20:31:18 +0000
+++ lib/lp/codehosting/tests/test_bzrutils.py	2011-05-19 13:31:09 +0000
@@ -31,7 +31,7 @@
     )
 from bzrlib.tests.per_branch import (
     branch_scenarios,
-    TestCaseWithBzrDir,
+    TestCaseWithControlDir,
     )
 from bzrlib.transport import chroot
 from lazr.uri import URI
@@ -51,7 +51,7 @@
 from lp.codehosting.tests.helpers import TestResultWrapper
 
 
-class TestGetBranchStackedOnURL(TestCaseWithBzrDir):
+class TestGetBranchStackedOnURL(TestCaseWithControlDir):
     """Tests for get_branch_stacked_on_url()."""
 
     def __str__(self):
@@ -63,7 +63,7 @@
         # test are dropped, so the daemon threads serving those branches can
         # exit.
         gc.collect()
-        TestCaseWithBzrDir.tearDown(self)
+        TestCaseWithControlDir.tearDown(self)
 
     def run(self, result=None):
         """Run the test, with the result wrapped so that it knows about skips.

=== modified file 'utilities/sourcedeps.cache'
--- utilities/sourcedeps.cache	2011-05-24 17:13:58 +0000
+++ utilities/sourcedeps.cache	2011-06-01 18:58:15 +0000
@@ -1,8 +1,4 @@
 {
-    "bzr-builder": [
-        68, 
-        "launchpad@pqm.canonical.com-20101123183213-777lz46xgagn1deg"
-    ], 
     "testresources": [
         16, 
         "robertc@robertcollins.net-20050911111209-ee5da49011cf936a"
@@ -20,8 +16,8 @@
         "launchpad@pqm.canonical.com-20100325120516-q8to5dx3gga4wlvi"
     ], 
     "subvertpy": [
-        2042, 
-        "launchpad@pqm.canonical.com-20100727083620-u93rikomkjfj82dw"
+        2043, 
+        "launchpad@pqm.canonical.com-20110520175118-iovx148eje6qt7jt"
     ], 
     "python-debian": [
         186, 
@@ -31,40 +27,44 @@
         24, 
         "launchpad@pqm.canonical.com-20100601182722-wo7h2fh0fvyw3aaq"
     ], 
-    "lpreview": [
-        23, 
-        "launchpad@pqm.canonical.com-20090720061538-euyh68ifavhy0pi8"
-    ], 
     "bzr-git": [
-        258, 
-        "launchpad@pqm.canonical.com-20100812210320-i61pvvvo9mjo2wp7"
+        259, 
+        "launchpad@pqm.canonical.com-20110601140035-gl5merbechngjw5s"
+    ], 
+    "loggerhead": [
+        445, 
+        "john@arbash-meinel.com-20110325141442-536j4be3x0c464zy"
+    ], 
+    "bzr-builder": [
+        68, 
+        "launchpad@pqm.canonical.com-20101123183213-777lz46xgagn1deg"
     ], 
     "bzr-loom": [
-        48, 
-        "launchpad@pqm.canonical.com-20100806142619-4huubp7dmz6ax9j2"
+        49, 
+        "launchpad@pqm.canonical.com-20110601122412-54vo3k8yae9i2zve"
     ], 
     "old_xmlplus": [
         4, 
         "sinzui-20090526164636-1swugzupwvjgomo4"
     ], 
-    "loggerhead": [
-        445, 
-        "john@arbash-meinel.com-20110325141442-536j4be3x0c464zy"
+    "lpreview": [
+        23, 
+        "launchpad@pqm.canonical.com-20090720061538-euyh68ifavhy0pi8"
     ], 
     "difftacular": [
         6, 
         "aaron@aaronbentley.com-20100715135013-uoi3q430urx9gwb8"
     ], 
     "bzr-svn": [
-        2710, 
-        "launchpad@pqm.canonical.com-20100830004921-6c4hehto20axdkn6"
+        2712, 
+        "launchpad@pqm.canonical.com-20110601185515-xaik1gqvhtr5jiph"
     ], 
     "bzr-hg": [
-        283, 
-        "launchpad@pqm.canonical.com-20100814010415-lzqc5jufq5u1hd44"
+        285, 
+        "launchpad@pqm.canonical.com-20110601185713-cy6wd1u0iim2m9am"
     ], 
     "dulwich": [
-        424, 
-        "launchpad@pqm.canonical.com-20100812211021-x1uaubka3ael1j62"
+        426, 
+        "launchpad@pqm.canonical.com-20110520175715-e90dzs8os0kotbm9"
     ]
 }
\ No newline at end of file

=== modified file 'utilities/sourcedeps.conf'
--- utilities/sourcedeps.conf	2011-04-21 01:13:19 +0000
+++ utilities/sourcedeps.conf	2011-06-01 18:58:15 +0000
@@ -1,10 +1,10 @@
 bzr-builder lp:~launchpad-pqm/bzr-builder/trunk;revno=68
-bzr-git lp:~launchpad-pqm/bzr-git/devel;revno=258
-bzr-hg lp:~launchpad-pqm/bzr-hg/devel;revno=283
-bzr-loom lp:~launchpad-pqm/bzr-loom/trunk;revno=48
-bzr-svn lp:~launchpad-pqm/bzr-svn/devel;revno=2710
+bzr-git lp:~launchpad-pqm/bzr-git/devel;revno=259
+bzr-hg lp:~launchpad-pqm/bzr-hg/devel;revno=285
+bzr-loom lp:~launchpad-pqm/bzr-loom/trunk;revno=49
+bzr-svn lp:~launchpad-pqm/bzr-svn/devel;revno=2712
 cscvs lp:~launchpad-pqm/launchpad-cscvs/devel;revno=432
-dulwich lp:~launchpad-pqm/dulwich/devel;revno=424
+dulwich lp:~launchpad-pqm/dulwich/devel;revno=426
 difftacular lp:difftacular;revno=6
 loggerhead lp:~loggerhead-team/loggerhead/trunk-rich;revno=445
 lpreview lp:~launchpad-pqm/bzr-lpreview/devel;revno=23
@@ -12,6 +12,6 @@
 old_xmlplus lp:~launchpad-pqm/dtdparser/trunk;revno=4
 pygettextpo lp:~launchpad-pqm/pygettextpo/trunk;revno=24
 pygpgme lp:~launchpad-pqm/pygpgme/devel;revno=49
-subvertpy lp:~launchpad-pqm/subvertpy/trunk;revno=2042
+subvertpy lp:~launchpad-pqm/subvertpy/trunk;revno=2043
 python-debian lp:~launchpad-pqm/python-debian/devel;revno=186
 testresources lp:~launchpad-pqm/testresources/dev;revno=16

=== modified file 'versions.cfg'
--- versions.cfg	2011-05-19 10:48:22 +0000
+++ versions.cfg	2011-06-01 11:59:02 +0000
@@ -6,8 +6,7 @@
 
 ampoule = 0.2.0
 BeautifulSoup = 3.1.0.1
-# from lp:~launchpad/bzr/2.2-lp
-bzr = 2.2.2-lp-2
+bzr = 2.3.3
 chameleon.core = 1.0b35
 chameleon.zpt = 1.0b17
 ClientForm = 0.2.10

